# This file was auto-generated by Fern from our API Definition.

import typing

from .activity_column_expr import ActivityColumnExpr
from .aggregate_expr import AggregateExpr
from .blood_pressure_timeseries_expr import BloodPressureTimeseriesExpr
from .body_column_expr import BodyColumnExpr
from .chronotype_value_macro_expr import ChronotypeValueMacroExpr
from .discrete_timeseries_expr import DiscreteTimeseriesExpr
from .group_key_column_expr import GroupKeyColumnExpr
from .index_column_expr import IndexColumnExpr
from .interval_timeseries_expr import IntervalTimeseriesExpr
from .note_timeseries_expr import NoteTimeseriesExpr
from .sleep_column_expr import SleepColumnExpr
from .sleep_score_value_macro_expr import SleepScoreValueMacroExpr
from .temperature_timeseries_expr import TemperatureTimeseriesExpr
from .unrecognized_value_macro_expr import UnrecognizedValueMacroExpr
from .workout_column_expr import WorkoutColumnExpr
from .workout_duration_timeseries_expr import WorkoutDurationTimeseriesExpr

QuerySelectItem = typing.Union[
    AggregateExpr,
    GroupKeyColumnExpr,
    SleepColumnExpr,
    ActivityColumnExpr,
    WorkoutColumnExpr,
    BodyColumnExpr,
    IndexColumnExpr,
    SleepScoreValueMacroExpr,
    ChronotypeValueMacroExpr,
    UnrecognizedValueMacroExpr,
    DiscreteTimeseriesExpr,
    IntervalTimeseriesExpr,
    BloodPressureTimeseriesExpr,
    TemperatureTimeseriesExpr,
    WorkoutDurationTimeseriesExpr,
    NoteTimeseriesExpr,
]
